@@ -1,7 +1,7 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CL-USER; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/cl-who/packages.lisp,v 1.18 2008/03/27 23:17:55 edi Exp $
+;;; $Header: /usr/local/cvsrep/cl-who/packages.lisp,v 1.21 2009/01/26 11:10:49 edi Exp $
 
-;;; Copyright (c) 2003-2008, Dr. Edmund Weitz. All rights reserved.
+;;; Copyright (c) 2003-2009, Dr. Edmund Weitz. All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -33,10 +33,12 @@
   (:use :cl)
   (:nicknames :who)
   #+:sbcl (:shadow :defconstant)
+  #+:sb-package-locks (:lock t)
   (:export :*attribute-quote-char*
            :*escape-char-p*
            :*prologue*
            :*downcase-tokens-p*
+           :*html-no-indent-tags*
            :*html-empty-tags*
            :*html-empty-tag-aware-p*
            :conc
@@ -50,14 +52,12 @@
            :escape-char-minimal-plus-quotes
            :escape-string
            :escape-string-all
-           :escape-string-iso-8859
            :escape-string-iso-8859-1
            :escape-string-minimal
            :escape-string-minimal-plus-quotes
            :fmt
            :htm
            :html-mode
-           :show-html-expansion
            :str
            :with-html-output
            :with-html-output-to-string))
